moody.m API documentation

# Module `moody.m`

## Sub-modules

`moody.m.b_send`

  Generated wrapper for BSend Solidity contract.

`moody.m.bases`

  Base wrapper class for accessing ethereum smart contracts.

`moody.m.beri_coin`

  Generated wrapper for BeriCoin Solidity contract.

`moody.m.blockhash_store`

  Generated wrapper for BlockhashStore Solidity contract.

`moody.m.c_token`

  Generated wrapper for CToken Solidity contract.

`moody.m.eth2_multi_deposit`

  Generated wrapper for Eth2MultiDeposit Solidity contract.

`moody.m.layer_zero_u_s_d_t`

  Generated wrapper for LayerZeroUSDT Solidity contract.

`moody.m.multicall`

  Generated wrapper for Multicall Solidity contract.

`moody.m.multicall2`

  Generated wrapper for Multicall2 Solidity contract.

`moody.m.oracle`

  Generated wrapper for Oracle Solidity contract.

`moody.m.pharaohs`

  Generated wrapper for pharaohs Solidity contract.

`moody.m.tc20`

  Generated wrapper for Tc20 Solidity contract.

`moody.m.tether_token2`

  Generated wrapper for TetherToken2 Solidity contract.

`moody.m.tx_params`

  Transaction parameters for use with contract wrappers.

`moody.m.uniswap_v2_erc20`

  Generated wrapper for UniswapV2ERC20 Solidity contract.

`moody.m.uniswap_v2_factory`

  Generated wrapper for UniswapV2Factory Solidity contract.

`moody.m.uniswap_v2_router02`

  Generated wrapper for UniswapV2Router02 Solidity contract.

`moody.m.v_r_f_consumer`

  Generated wrapper for VRFConsumer Solidity contract.

`moody.m.v_r_f_coordinator`

  Generated wrapper for VRFCoordinator Solidity contract.